@@ -771,8 +771,9 @@ def compute_alpha_signal_rsilo(df=None, core_tokens=['BTC', 'ETH'], rsi_lookback
     ### we rebalance monday morning
     def get_filter_date(row,rebalancing_day=6):
         ##### to get the proper daily close
-        #### we only keep the signal that has been emitted the day before at 23h and pushed there
-        if row['weekday'] == rebalancing_day and row['hour'] == 0:
+        #### we only keep the signal that has been emitted the day after
+        next_day = (rebalancing_day+1)%7
+        if row['weekday'] == next_day and row['hour'] == 0:
             return True
         else:
             return False
